# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import memory_pb2 as memory__pb2


class MemoryGraphStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Satisfy = channel.unary_unary(
            "/service.MemoryGraph/Satisfy",
            request_serializer=memory__pb2.SatisfyRequest.SerializeToString,
            response_deserializer=memory__pb2.SatisfyResponse.FromString,
        )
        self.Register = channel.unary_unary(
            "/service.MemoryGraph/Register",
            request_serializer=memory__pb2.RegisterRequest.SerializeToString,
            response_deserializer=memory__pb2.Response.FromString,
        )


class MemoryGraphServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Satisfy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_MemoryGraphServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Satisfy": grpc.unary_unary_rpc_method_handler(
            servicer.Satisfy,
            request_deserializer=memory__pb2.SatisfyRequest.FromString,
            response_serializer=memory__pb2.SatisfyResponse.SerializeToString,
        ),
        "Register": grpc.unary_unary_rpc_method_handler(
            servicer.Register,
            request_deserializer=memory__pb2.RegisterRequest.FromString,
            response_serializer=memory__pb2.Response.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "service.MemoryGraph", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class MemoryGraph(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Satisfy(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/service.MemoryGraph/Satisfy",
            memory__pb2.SatisfyRequest.SerializeToString,
            memory__pb2.SatisfyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Register(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/service.MemoryGraph/Register",
            memory__pb2.RegisterRequest.SerializeToString,
            memory__pb2.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
